package oslogin
import "cloud.google.com/go/oslogin/apiv1"
Package oslogin is an auto-generated package for the Cloud OS Login API.
You can use OS Login to manage access to your VM instances using IAM roles.
General documentation
For information that is relevant for all client libraries please reference https://pkg.go.dev/cloud.google.com/go#pkg-overview. Some information on this page includes:
- Authentication and Authorization
- Timeouts and Cancellation
- Testing against Client Libraries
- Debugging Client Libraries
- Inspecting errors
Example usage
To get started with this package, create a client.
// go get cloud.google.com/go/oslogin/apiv1@latest
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
The client will use your default application credentials. Clients should be reused instead of created as needed. The methods of Client are safe for concurrent use by multiple goroutines. The returned client must be Closed when it is done being used.
Using the Client
The following is an example of making an API call with the newly created client, mentioned above.
req := &osloginpb.CreateSshPublicKeyRequest{
// TODO: Fill request struct fields.
// See https://pkg.go.dev/cloud.google.com/go/oslogin/apiv1/osloginpb#CreateSshPublicKeyRequest.
}
resp, err := c.CreateSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
Use of Context
The ctx passed to NewClient is used for authentication requests and for creating the underlying connection, but is not used for subsequent calls. Individual methods on the client use the ctx given to them.
To close the open connection, use the Close() method.
Index ¶
- func DefaultAuthScopes() []string
- type CallOptions
- type Client
- func NewClient(ctx context.Context, opts ...option.ClientOption) (*Client, error)
- func NewRESTClient(ctx context.Context, opts ...option.ClientOption) (*Client, error)
- func (c *Client) Close() error
- func (c *Client) Connection() *grpc.ClientConn
- func (c *Client) CreateSshPublicKey(ctx context.Context, req *osloginpb.CreateSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
- func (c *Client) DeletePosixAccount(ctx context.Context, req *osloginpb.DeletePosixAccountRequest, opts ...gax.CallOption) error
- func (c *Client) DeleteSshPublicKey(ctx context.Context, req *osloginpb.DeleteSshPublicKeyRequest, opts ...gax.CallOption) error
- func (c *Client) GetLoginProfile(ctx context.Context, req *osloginpb.GetLoginProfileRequest, opts ...gax.CallOption) (*osloginpb.LoginProfile, error)
- func (c *Client) GetSshPublicKey(ctx context.Context, req *osloginpb.GetSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
- func (c *Client) ImportSshPublicKey(ctx context.Context, req *osloginpb.ImportSshPublicKeyRequest, opts ...gax.CallOption) (*osloginpb.ImportSshPublicKeyResponse, error)
- func (c *Client) UpdateSshPublicKey(ctx context.Context, req *osloginpb.UpdateSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
Examples ¶
- Client.CreateSshPublicKey
- Client.DeletePosixAccount
- Client.DeleteSshPublicKey
- Client.GetLoginProfile
- Client.GetSshPublicKey
- Client.ImportSshPublicKey
- Client.UpdateSshPublicKey
- NewClient
- NewRESTClient
Functions ¶
func DefaultAuthScopes ¶
func DefaultAuthScopes() []string
DefaultAuthScopes reports the default set of authentication scopes to use with this package.
Types ¶
type CallOptions ¶
type CallOptions struct {
CreateSshPublicKey []gax.CallOption
DeletePosixAccount []gax.CallOption
DeleteSshPublicKey []gax.CallOption
GetLoginProfile []gax.CallOption
GetSshPublicKey []gax.CallOption
ImportSshPublicKey []gax.CallOption
UpdateSshPublicKey []gax.CallOption
}
CallOptions contains the retry settings for each method of Client.
type Client ¶
type Client struct {
// The call options for this service.
CallOptions *CallOptions
// contains filtered or unexported fields
}
Client is a client for interacting with Cloud OS Login API. Methods, except Close, may be called concurrently. However, fields must not be modified concurrently with method calls.
Cloud OS Login API
The Cloud OS Login API allows you to manage users and their associated SSH public keys for logging into virtual machines on Google Cloud Platform.
func NewClient ¶
NewClient creates a new os login service client based on gRPC. The returned client must be Closed when it is done being used to clean up its underlying connections.
Cloud OS Login API
The Cloud OS Login API allows you to manage users and their associated SSH
public keys for logging into virtual machines on Google Cloud Platform.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
// TODO: Use client.
_ = c
}
func NewRESTClient ¶
NewRESTClient creates a new os login service rest client.
Cloud OS Login API
The Cloud OS Login API allows you to manage users and their associated SSH
public keys for logging into virtual machines on Google Cloud Platform.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewRESTClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
// TODO: Use client.
_ = c
}
func (*Client) Close ¶
Close closes the connection to the API service. The user should invoke this when the client is no longer required.
func (*Client) Connection ¶
func (c *Client) Connection() *grpc.ClientConn
Connection returns a connection to the API service.
Deprecated: Connections are now pooled so this method does not always return the same resource.
func (*Client) CreateSshPublicKey ¶
func (c *Client) CreateSshPublicKey(ctx context.Context, req *osloginpb.CreateSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
CreateSshPublicKey create an SSH public key
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "cloud.google.com/go/oslogin/apiv1/osloginpb"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
req := &osloginpb.CreateSshPublicKeyRequest{
// TODO: Fill request struct fields.
// See https://pkg.go.dev/cloud.google.com/go/oslogin/apiv1/osloginpb#CreateSshPublicKeyRequest.
}
resp, err := c.CreateSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
func (*Client) DeletePosixAccount ¶
func (c *Client) DeletePosixAccount(ctx context.Context, req *osloginpb.DeletePosixAccountRequest, opts ...gax.CallOption) error
DeletePosixAccount deletes a POSIX account.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "cloud.google.com/go/oslogin/apiv1/osloginpb"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
req := &osloginpb.DeletePosixAccountRequest{
// TODO: Fill request struct fields.
// See https://pkg.go.dev/cloud.google.com/go/oslogin/apiv1/osloginpb#DeletePosixAccountRequest.
}
err = c.DeletePosixAccount(ctx, req)
if err != nil {
// TODO: Handle error.
}
}
func (*Client) DeleteSshPublicKey ¶
func (c *Client) DeleteSshPublicKey(ctx context.Context, req *osloginpb.DeleteSshPublicKeyRequest, opts ...gax.CallOption) error
DeleteSshPublicKey deletes an SSH public key.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "cloud.google.com/go/oslogin/apiv1/osloginpb"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
req := &osloginpb.DeleteSshPublicKeyRequest{
// TODO: Fill request struct fields.
// See https://pkg.go.dev/cloud.google.com/go/oslogin/apiv1/osloginpb#DeleteSshPublicKeyRequest.
}
err = c.DeleteSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
}
func (*Client) GetLoginProfile ¶
func (c *Client) GetLoginProfile(ctx context.Context, req *osloginpb.GetLoginProfileRequest, opts ...gax.CallOption) (*osloginpb.LoginProfile, error)
GetLoginProfile retrieves the profile information used for logging in to a virtual machine
on Google Compute Engine.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "cloud.google.com/go/oslogin/apiv1/osloginpb"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
req := &osloginpb.GetLoginProfileRequest{
// TODO: Fill request struct fields.
// See https://pkg.go.dev/cloud.google.com/go/oslogin/apiv1/osloginpb#GetLoginProfileRequest.
}
resp, err := c.GetLoginProfile(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
func (*Client) GetSshPublicKey ¶
func (c *Client) GetSshPublicKey(ctx context.Context, req *osloginpb.GetSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
GetSshPublicKey retrieves an SSH public key.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "cloud.google.com/go/oslogin/apiv1/osloginpb"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
req := &osloginpb.GetSshPublicKeyRequest{
// TODO: Fill request struct fields.
// See https://pkg.go.dev/cloud.google.com/go/oslogin/apiv1/osloginpb#GetSshPublicKeyRequest.
}
resp, err := c.GetSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
func (*Client) ImportSshPublicKey ¶
func (c *Client) ImportSshPublicKey(ctx context.Context, req *osloginpb.ImportSshPublicKeyRequest, opts ...gax.CallOption) (*osloginpb.ImportSshPublicKeyResponse, error)
ImportSshPublicKey adds an SSH public key and returns the profile information. Default POSIX
account information is set when no username and UID exist as part of the
login profile.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "cloud.google.com/go/oslogin/apiv1/osloginpb"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
req := &osloginpb.ImportSshPublicKeyRequest{
// TODO: Fill request struct fields.
// See https://pkg.go.dev/cloud.google.com/go/oslogin/apiv1/osloginpb#ImportSshPublicKeyRequest.
}
resp, err := c.ImportSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
func (*Client) UpdateSshPublicKey ¶
func (c *Client) UpdateSshPublicKey(ctx context.Context, req *osloginpb.UpdateSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
UpdateSshPublicKey updates an SSH public key and returns the profile information. This method
supports patch semantics.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "cloud.google.com/go/oslogin/apiv1/osloginpb"
)
func main() {
ctx := context.Background()
// This snippet has been automatically generated and should be regarded as a code template only.
// It will require modifications to work:
// - It may require correct/in-range values for request initialization.
// - It may require specifying regional endpoints when creating the service client as shown in:
// https://pkg.go.dev/cloud.google.com/go#hdr-Client_Options
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
defer c.Close()
req := &osloginpb.UpdateSshPublicKeyRequest{
// TODO: Fill request struct fields.
// See https://pkg.go.dev/cloud.google.com/go/oslogin/apiv1/osloginpb#UpdateSshPublicKeyRequest.
}
resp, err := c.UpdateSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
Source Files ¶
auxiliary.go auxiliary_go123.go doc.go helpers.go os_login_client.go version.go
Directories ¶
| Path | Synopsis |
|---|---|
| apiv1/osloginpb |
- Version
- v1.14.7 (latest)
- Published
- Sep 18, 2025
- Platform
- linux/amd64
- Imports
- 25 packages
- Last checked
- 5 months ago –
Tools for package owners.