Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterOsLoginServiceServer(s grpc.ServiceRegistrar, srv OsLoginServiceServer)
- type CreateSshPublicKeyRequest
- func (*CreateSshPublicKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CreateSshPublicKeyRequest) GetParent() string
- func (x *CreateSshPublicKeyRequest) GetSshPublicKey() *commonpb.SshPublicKey
- func (*CreateSshPublicKeyRequest) ProtoMessage()
- func (x *CreateSshPublicKeyRequest) ProtoReflect() protoreflect.Message
- func (x *CreateSshPublicKeyRequest) Reset()
- func (x *CreateSshPublicKeyRequest) String() string
- type DeletePosixAccountRequest
- func (*DeletePosixAccountRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeletePosixAccountRequest) GetName() string
- func (*DeletePosixAccountRequest) ProtoMessage()
- func (x *DeletePosixAccountRequest) ProtoReflect() protoreflect.Message
- func (x *DeletePosixAccountRequest) Reset()
- func (x *DeletePosixAccountRequest) String() string
- type DeleteSshPublicKeyRequest
- func (*DeleteSshPublicKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *DeleteSshPublicKeyRequest) GetName() string
- func (*DeleteSshPublicKeyRequest) ProtoMessage()
- func (x *DeleteSshPublicKeyRequest) ProtoReflect() protoreflect.Message
- func (x *DeleteSshPublicKeyRequest) Reset()
- func (x *DeleteSshPublicKeyRequest) String() string
- type GetLoginProfileRequest
- func (*GetLoginProfileRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetLoginProfileRequest) GetName() string
- func (x *GetLoginProfileRequest) GetProjectId() string
- func (x *GetLoginProfileRequest) GetSystemId() string
- func (x *GetLoginProfileRequest) GetView() LoginProfileView
- func (*GetLoginProfileRequest) ProtoMessage()
- func (x *GetLoginProfileRequest) ProtoReflect() protoreflect.Message
- func (x *GetLoginProfileRequest) Reset()
- func (x *GetLoginProfileRequest) String() string
- type GetSshPublicKeyRequest
- func (*GetSshPublicKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *GetSshPublicKeyRequest) GetName() string
- func (*GetSshPublicKeyRequest) ProtoMessage()
- func (x *GetSshPublicKeyRequest) ProtoReflect() protoreflect.Message
- func (x *GetSshPublicKeyRequest) Reset()
- func (x *GetSshPublicKeyRequest) String() string
- type ImportSshPublicKeyRequest
- func (*ImportSshPublicKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *ImportSshPublicKeyRequest) GetParent() string
- func (x *ImportSshPublicKeyRequest) GetProjectId() string
- func (x *ImportSshPublicKeyRequest) GetRegions() []string
- func (x *ImportSshPublicKeyRequest) GetSshPublicKey() *commonpb.SshPublicKey
- func (x *ImportSshPublicKeyRequest) GetView() LoginProfileView
- func (*ImportSshPublicKeyRequest) ProtoMessage()
- func (x *ImportSshPublicKeyRequest) ProtoReflect() protoreflect.Message
- func (x *ImportSshPublicKeyRequest) Reset()
- func (x *ImportSshPublicKeyRequest) String() string
- type ImportSshPublicKeyResponse
- func (*ImportSshPublicKeyResponse) Descriptor() ([]byte, []int)deprecated
- func (x *ImportSshPublicKeyResponse) GetDetails() string
- func (x *ImportSshPublicKeyResponse) GetLoginProfile() *LoginProfile
- func (*ImportSshPublicKeyResponse) ProtoMessage()
- func (x *ImportSshPublicKeyResponse) ProtoReflect() protoreflect.Message
- func (x *ImportSshPublicKeyResponse) Reset()
- func (x *ImportSshPublicKeyResponse) String() string
- type LoginProfile
- func (*LoginProfile) Descriptor() ([]byte, []int)deprecated
- func (x *LoginProfile) GetName() string
- func (x *LoginProfile) GetPosixAccounts() []*commonpb.PosixAccount
- func (x *LoginProfile) GetSecurityKeys() []*SecurityKey
- func (x *LoginProfile) GetSshPublicKeys() map[string]*commonpb.SshPublicKey
- func (*LoginProfile) ProtoMessage()
- func (x *LoginProfile) ProtoReflect() protoreflect.Message
- func (x *LoginProfile) Reset()
- func (x *LoginProfile) String() string
- type LoginProfileView
- func (LoginProfileView) Descriptor() protoreflect.EnumDescriptor
- func (x LoginProfileView) Enum() *LoginProfileView
- func (LoginProfileView) EnumDescriptor() ([]byte, []int)deprecated
- func (x LoginProfileView) Number() protoreflect.EnumNumber
- func (x LoginProfileView) String() string
- func (LoginProfileView) Type() protoreflect.EnumType
- type OsLoginServiceClient
- type OsLoginServiceServer
- type SecurityKey
- func (*SecurityKey) Descriptor() ([]byte, []int)deprecated
- func (x *SecurityKey) GetDeviceNickname() string
- func (x *SecurityKey) GetPrivateKey() string
- func (x *SecurityKey) GetProtocolType() isSecurityKey_ProtocolType
- func (x *SecurityKey) GetPublicKey() string
- func (x *SecurityKey) GetUniversalTwoFactor() *UniversalTwoFactor
- func (x *SecurityKey) GetWebAuthn() *WebAuthn
- func (*SecurityKey) ProtoMessage()
- func (x *SecurityKey) ProtoReflect() protoreflect.Message
- func (x *SecurityKey) Reset()
- func (x *SecurityKey) String() string
- type SecurityKey_UniversalTwoFactor
- type SecurityKey_WebAuthn
- type SignSshPublicKeyRequest
- func (*SignSshPublicKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *SignSshPublicKeyRequest) GetParent() string
- func (x *SignSshPublicKeyRequest) GetSshPublicKey() string
- func (*SignSshPublicKeyRequest) ProtoMessage()
- func (x *SignSshPublicKeyRequest) ProtoReflect() protoreflect.Message
- func (x *SignSshPublicKeyRequest) Reset()
- func (x *SignSshPublicKeyRequest) String() string
- type SignSshPublicKeyResponse
- func (*SignSshPublicKeyResponse) Descriptor() ([]byte, []int)deprecated
- func (x *SignSshPublicKeyResponse) GetSignedSshPublicKey() string
- func (*SignSshPublicKeyResponse) ProtoMessage()
- func (x *SignSshPublicKeyResponse) ProtoReflect() protoreflect.Message
- func (x *SignSshPublicKeyResponse) Reset()
- func (x *SignSshPublicKeyResponse) String() string
- type UnimplementedOsLoginServiceServer
- func (UnimplementedOsLoginServiceServer) CreateSshPublicKey(context.Context, *CreateSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
- func (UnimplementedOsLoginServiceServer) DeletePosixAccount(context.Context, *DeletePosixAccountRequest) (*emptypb.Empty, error)
- func (UnimplementedOsLoginServiceServer) DeleteSshPublicKey(context.Context, *DeleteSshPublicKeyRequest) (*emptypb.Empty, error)
- func (UnimplementedOsLoginServiceServer) GetLoginProfile(context.Context, *GetLoginProfileRequest) (*LoginProfile, error)
- func (UnimplementedOsLoginServiceServer) GetSshPublicKey(context.Context, *GetSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
- func (UnimplementedOsLoginServiceServer) ImportSshPublicKey(context.Context, *ImportSshPublicKeyRequest) (*ImportSshPublicKeyResponse, error)
- func (UnimplementedOsLoginServiceServer) SignSshPublicKey(context.Context, *SignSshPublicKeyRequest) (*SignSshPublicKeyResponse, error)
- func (UnimplementedOsLoginServiceServer) UpdateSshPublicKey(context.Context, *UpdateSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
- type UniversalTwoFactor
- func (*UniversalTwoFactor) Descriptor() ([]byte, []int)deprecated
- func (x *UniversalTwoFactor) GetAppId() string
- func (*UniversalTwoFactor) ProtoMessage()
- func (x *UniversalTwoFactor) ProtoReflect() protoreflect.Message
- func (x *UniversalTwoFactor) Reset()
- func (x *UniversalTwoFactor) String() string
- type UnsafeOsLoginServiceServer
- type UpdateSshPublicKeyRequest
- func (*UpdateSshPublicKeyRequest) Descriptor() ([]byte, []int)deprecated
- func (x *UpdateSshPublicKeyRequest) GetName() string
- func (x *UpdateSshPublicKeyRequest) GetSshPublicKey() *commonpb.SshPublicKey
- func (x *UpdateSshPublicKeyRequest) GetUpdateMask() *fieldmaskpb.FieldMask
- func (*UpdateSshPublicKeyRequest) ProtoMessage()
- func (x *UpdateSshPublicKeyRequest) ProtoReflect() protoreflect.Message
- func (x *UpdateSshPublicKeyRequest) Reset()
- func (x *UpdateSshPublicKeyRequest) String() string
- type WebAuthn
Constants ¶
const ( OsLoginService_CreateSshPublicKey_FullMethodName = "/google.cloud.oslogin.v1beta.OsLoginService/CreateSshPublicKey" OsLoginService_DeletePosixAccount_FullMethodName = "/google.cloud.oslogin.v1beta.OsLoginService/DeletePosixAccount" OsLoginService_DeleteSshPublicKey_FullMethodName = "/google.cloud.oslogin.v1beta.OsLoginService/DeleteSshPublicKey" OsLoginService_GetLoginProfile_FullMethodName = "/google.cloud.oslogin.v1beta.OsLoginService/GetLoginProfile" OsLoginService_GetSshPublicKey_FullMethodName = "/google.cloud.oslogin.v1beta.OsLoginService/GetSshPublicKey" OsLoginService_ImportSshPublicKey_FullMethodName = "/google.cloud.oslogin.v1beta.OsLoginService/ImportSshPublicKey" OsLoginService_UpdateSshPublicKey_FullMethodName = "/google.cloud.oslogin.v1beta.OsLoginService/UpdateSshPublicKey" OsLoginService_SignSshPublicKey_FullMethodName = "/google.cloud.oslogin.v1beta.OsLoginService/SignSshPublicKey" )
Variables ¶
var ( LoginProfileView_name = map[int32]string{ 0: "LOGIN_PROFILE_VIEW_UNSPECIFIED", 1: "BASIC", 2: "SECURITY_KEY", } LoginProfileView_value = map[string]int32{ "LOGIN_PROFILE_VIEW_UNSPECIFIED": 0, "BASIC": 1, "SECURITY_KEY": 2, } )
Enum value maps for LoginProfileView.
var File_google_cloud_oslogin_v1beta_oslogin_proto protoreflect.FileDescriptor
var OsLoginService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "google.cloud.oslogin.v1beta.OsLoginService", HandlerType: (*OsLoginServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "CreateSshPublicKey", Handler: _OsLoginService_CreateSshPublicKey_Handler, }, { MethodName: "DeletePosixAccount", Handler: _OsLoginService_DeletePosixAccount_Handler, }, { MethodName: "DeleteSshPublicKey", Handler: _OsLoginService_DeleteSshPublicKey_Handler, }, { MethodName: "GetLoginProfile", Handler: _OsLoginService_GetLoginProfile_Handler, }, { MethodName: "GetSshPublicKey", Handler: _OsLoginService_GetSshPublicKey_Handler, }, { MethodName: "ImportSshPublicKey", Handler: _OsLoginService_ImportSshPublicKey_Handler, }, { MethodName: "UpdateSshPublicKey", Handler: _OsLoginService_UpdateSshPublicKey_Handler, }, { MethodName: "SignSshPublicKey", Handler: _OsLoginService_SignSshPublicKey_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "google/cloud/oslogin/v1beta/oslogin.proto", }
OsLoginService_ServiceDesc is the grpc.ServiceDesc for OsLoginService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterOsLoginServiceServer ¶
func RegisterOsLoginServiceServer(s grpc.ServiceRegistrar, srv OsLoginServiceServer)
Types ¶
type CreateSshPublicKeyRequest ¶ added in v1.8.0
type CreateSshPublicKeyRequest struct {
// Required. The unique ID for the user in format `users/{user}`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. The SSH public key and expiration time.
SshPublicKey *commonpb.SshPublicKey `protobuf:"bytes,2,opt,name=ssh_public_key,json=sshPublicKey,proto3" json:"ssh_public_key,omitempty"`
// contains filtered or unexported fields
}
A request message for creating an SSH public key.
func (*CreateSshPublicKeyRequest) Descriptor
deprecated
added in
v1.8.0
func (*CreateSshPublicKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use CreateSshPublicKeyRequest.ProtoReflect.Descriptor instead.
func (*CreateSshPublicKeyRequest) GetParent ¶ added in v1.8.0
func (x *CreateSshPublicKeyRequest) GetParent() string
func (*CreateSshPublicKeyRequest) GetSshPublicKey ¶ added in v1.8.0
func (x *CreateSshPublicKeyRequest) GetSshPublicKey() *commonpb.SshPublicKey
func (*CreateSshPublicKeyRequest) ProtoMessage ¶ added in v1.8.0
func (*CreateSshPublicKeyRequest) ProtoMessage()
func (*CreateSshPublicKeyRequest) ProtoReflect ¶ added in v1.8.0
func (x *CreateSshPublicKeyRequest) ProtoReflect() protoreflect.Message
func (*CreateSshPublicKeyRequest) Reset ¶ added in v1.8.0
func (x *CreateSshPublicKeyRequest) Reset()
func (*CreateSshPublicKeyRequest) String ¶ added in v1.8.0
func (x *CreateSshPublicKeyRequest) String() string
type DeletePosixAccountRequest ¶
type DeletePosixAccountRequest struct {
// Required. A reference to the POSIX account to update. POSIX accounts are
// identified by the project ID they are associated with. A reference to the
// POSIX account is in format `users/{user}/projects/{project}`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
A request message for deleting a POSIX account entry.
func (*DeletePosixAccountRequest) Descriptor
deprecated
func (*DeletePosixAccountRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeletePosixAccountRequest.ProtoReflect.Descriptor instead.
func (*DeletePosixAccountRequest) GetName ¶
func (x *DeletePosixAccountRequest) GetName() string
func (*DeletePosixAccountRequest) ProtoMessage ¶
func (*DeletePosixAccountRequest) ProtoMessage()
func (*DeletePosixAccountRequest) ProtoReflect ¶
func (x *DeletePosixAccountRequest) ProtoReflect() protoreflect.Message
func (*DeletePosixAccountRequest) Reset ¶
func (x *DeletePosixAccountRequest) Reset()
func (*DeletePosixAccountRequest) String ¶
func (x *DeletePosixAccountRequest) String() string
type DeleteSshPublicKeyRequest ¶
type DeleteSshPublicKeyRequest struct {
// Required. The fingerprint of the public key to update. Public keys are
// identified by their SHA-256 fingerprint. The fingerprint of the public key
// is in format `users/{user}/sshPublicKeys/{fingerprint}`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
A request message for deleting an SSH public key.
func (*DeleteSshPublicKeyRequest) Descriptor
deprecated
func (*DeleteSshPublicKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use DeleteSshPublicKeyRequest.ProtoReflect.Descriptor instead.
func (*DeleteSshPublicKeyRequest) GetName ¶
func (x *DeleteSshPublicKeyRequest) GetName() string
func (*DeleteSshPublicKeyRequest) ProtoMessage ¶
func (*DeleteSshPublicKeyRequest) ProtoMessage()
func (*DeleteSshPublicKeyRequest) ProtoReflect ¶
func (x *DeleteSshPublicKeyRequest) ProtoReflect() protoreflect.Message
func (*DeleteSshPublicKeyRequest) Reset ¶
func (x *DeleteSshPublicKeyRequest) Reset()
func (*DeleteSshPublicKeyRequest) String ¶
func (x *DeleteSshPublicKeyRequest) String() string
type GetLoginProfileRequest ¶
type GetLoginProfileRequest struct {
// Required. The unique ID for the user in format `users/{user}`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The project ID of the Google Cloud Platform project.
ProjectId string `protobuf:"bytes,2,opt,name=project_id,json=projectId,proto3" json:"project_id,omitempty"`
// A system ID for filtering the results of the request.
SystemId string `protobuf:"bytes,3,opt,name=system_id,json=systemId,proto3" json:"system_id,omitempty"`
// The view configures whether to retrieve security keys information.
View LoginProfileView `protobuf:"varint,4,opt,name=view,proto3,enum=google.cloud.oslogin.v1beta.LoginProfileView" json:"view,omitempty"`
// contains filtered or unexported fields
}
A request message for retrieving the login profile information for a user.
func (*GetLoginProfileRequest) Descriptor
deprecated
func (*GetLoginProfileRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetLoginProfileRequest.ProtoReflect.Descriptor instead.
func (*GetLoginProfileRequest) GetName ¶
func (x *GetLoginProfileRequest) GetName() string
func (*GetLoginProfileRequest) GetProjectId ¶
func (x *GetLoginProfileRequest) GetProjectId() string
func (*GetLoginProfileRequest) GetSystemId ¶
func (x *GetLoginProfileRequest) GetSystemId() string
func (*GetLoginProfileRequest) GetView ¶ added in v1.8.0
func (x *GetLoginProfileRequest) GetView() LoginProfileView
func (*GetLoginProfileRequest) ProtoMessage ¶
func (*GetLoginProfileRequest) ProtoMessage()
func (*GetLoginProfileRequest) ProtoReflect ¶
func (x *GetLoginProfileRequest) ProtoReflect() protoreflect.Message
func (*GetLoginProfileRequest) Reset ¶
func (x *GetLoginProfileRequest) Reset()
func (*GetLoginProfileRequest) String ¶
func (x *GetLoginProfileRequest) String() string
type GetSshPublicKeyRequest ¶
type GetSshPublicKeyRequest struct {
// Required. The fingerprint of the public key to retrieve. Public keys are
// identified by their SHA-256 fingerprint. The fingerprint of the public key
// is in format `users/{user}/sshPublicKeys/{fingerprint}`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
A request message for retrieving an SSH public key.
func (*GetSshPublicKeyRequest) Descriptor
deprecated
func (*GetSshPublicKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use GetSshPublicKeyRequest.ProtoReflect.Descriptor instead.
func (*GetSshPublicKeyRequest) GetName ¶
func (x *GetSshPublicKeyRequest) GetName() string
func (*GetSshPublicKeyRequest) ProtoMessage ¶
func (*GetSshPublicKeyRequest) ProtoMessage()
func (*GetSshPublicKeyRequest) ProtoReflect ¶
func (x *GetSshPublicKeyRequest) ProtoReflect() protoreflect.Message
func (*GetSshPublicKeyRequest) Reset ¶
func (x *GetSshPublicKeyRequest) Reset()
func (*GetSshPublicKeyRequest) String ¶
func (x *GetSshPublicKeyRequest) String() string
type ImportSshPublicKeyRequest ¶
type ImportSshPublicKeyRequest struct {
// The unique ID for the user in format `users/{user}`.
Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
// Required. The SSH public key and expiration time.
SshPublicKey *commonpb.SshPublicKey `protobuf:"bytes,2,opt,name=ssh_public_key,json=sshPublicKey,proto3" json:"ssh_public_key,omitempty"`
// The project ID of the Google Cloud Platform project.
ProjectId string `protobuf:"bytes,3,opt,name=project_id,json=projectId,proto3" json:"project_id,omitempty"`
// The view configures whether to retrieve security keys information.
View LoginProfileView `protobuf:"varint,4,opt,name=view,proto3,enum=google.cloud.oslogin.v1beta.LoginProfileView" json:"view,omitempty"`
// Optional. The regions to which to assert that the key was written.
// If unspecified, defaults to all regions.
// Regions are listed at https://cloud.google.com/about/locations#region.
Regions []string `protobuf:"bytes,5,rep,name=regions,proto3" json:"regions,omitempty"`
// contains filtered or unexported fields
}
A request message for importing an SSH public key.
func (*ImportSshPublicKeyRequest) Descriptor
deprecated
func (*ImportSshPublicKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use ImportSshPublicKeyRequest.ProtoReflect.Descriptor instead.
func (*ImportSshPublicKeyRequest) GetParent ¶
func (x *ImportSshPublicKeyRequest) GetParent() string
func (*ImportSshPublicKeyRequest) GetProjectId ¶
func (x *ImportSshPublicKeyRequest) GetProjectId() string
func (*ImportSshPublicKeyRequest) GetRegions ¶ added in v1.13.0
func (x *ImportSshPublicKeyRequest) GetRegions() []string
func (*ImportSshPublicKeyRequest) GetSshPublicKey ¶
func (x *ImportSshPublicKeyRequest) GetSshPublicKey() *commonpb.SshPublicKey
func (*ImportSshPublicKeyRequest) GetView ¶ added in v1.8.0
func (x *ImportSshPublicKeyRequest) GetView() LoginProfileView
func (*ImportSshPublicKeyRequest) ProtoMessage ¶
func (*ImportSshPublicKeyRequest) ProtoMessage()
func (*ImportSshPublicKeyRequest) ProtoReflect ¶
func (x *ImportSshPublicKeyRequest) ProtoReflect() protoreflect.Message
func (*ImportSshPublicKeyRequest) Reset ¶
func (x *ImportSshPublicKeyRequest) Reset()
func (*ImportSshPublicKeyRequest) String ¶
func (x *ImportSshPublicKeyRequest) String() string
type ImportSshPublicKeyResponse ¶
type ImportSshPublicKeyResponse struct {
// The login profile information for the user.
LoginProfile *LoginProfile `protobuf:"bytes,1,opt,name=login_profile,json=loginProfile,proto3" json:"login_profile,omitempty"`
// Detailed information about import results.
Details string `protobuf:"bytes,2,opt,name=details,proto3" json:"details,omitempty"`
// contains filtered or unexported fields
}
A response message for importing an SSH public key.
func (*ImportSshPublicKeyResponse) Descriptor
deprecated
func (*ImportSshPublicKeyResponse) Descriptor() ([]byte, []int)
Deprecated: Use ImportSshPublicKeyResponse.ProtoReflect.Descriptor instead.
func (*ImportSshPublicKeyResponse) GetDetails ¶ added in v1.8.0
func (x *ImportSshPublicKeyResponse) GetDetails() string
func (*ImportSshPublicKeyResponse) GetLoginProfile ¶
func (x *ImportSshPublicKeyResponse) GetLoginProfile() *LoginProfile
func (*ImportSshPublicKeyResponse) ProtoMessage ¶
func (*ImportSshPublicKeyResponse) ProtoMessage()
func (*ImportSshPublicKeyResponse) ProtoReflect ¶
func (x *ImportSshPublicKeyResponse) ProtoReflect() protoreflect.Message
func (*ImportSshPublicKeyResponse) Reset ¶
func (x *ImportSshPublicKeyResponse) Reset()
func (*ImportSshPublicKeyResponse) String ¶
func (x *ImportSshPublicKeyResponse) String() string
type LoginProfile ¶
type LoginProfile struct {
// Required. A unique user ID.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// The list of POSIX accounts associated with the user.
PosixAccounts []*commonpb.PosixAccount `protobuf:"bytes,2,rep,name=posix_accounts,json=posixAccounts,proto3" json:"posix_accounts,omitempty"`
// A map from SSH public key fingerprint to the associated key object.
SshPublicKeys map[string]*commonpb.SshPublicKey `` /* 176-byte string literal not displayed */
// The registered security key credentials for a user.
SecurityKeys []*SecurityKey `protobuf:"bytes,5,rep,name=security_keys,json=securityKeys,proto3" json:"security_keys,omitempty"`
// contains filtered or unexported fields
}
The user profile information used for logging in to a virtual machine on Google Compute Engine.
func (*LoginProfile) Descriptor
deprecated
func (*LoginProfile) Descriptor() ([]byte, []int)
Deprecated: Use LoginProfile.ProtoReflect.Descriptor instead.
func (*LoginProfile) GetName ¶
func (x *LoginProfile) GetName() string
func (*LoginProfile) GetPosixAccounts ¶
func (x *LoginProfile) GetPosixAccounts() []*commonpb.PosixAccount
func (*LoginProfile) GetSecurityKeys ¶ added in v1.8.0
func (x *LoginProfile) GetSecurityKeys() []*SecurityKey
func (*LoginProfile) GetSshPublicKeys ¶
func (x *LoginProfile) GetSshPublicKeys() map[string]*commonpb.SshPublicKey
func (*LoginProfile) ProtoMessage ¶
func (*LoginProfile) ProtoMessage()
func (*LoginProfile) ProtoReflect ¶
func (x *LoginProfile) ProtoReflect() protoreflect.Message
func (*LoginProfile) Reset ¶
func (x *LoginProfile) Reset()
func (*LoginProfile) String ¶
func (x *LoginProfile) String() string
type LoginProfileView ¶ added in v1.8.0
type LoginProfileView int32
The login profile view limits the user content retrieved.
const ( // The default login profile view. The API defaults to the BASIC view. LoginProfileView_LOGIN_PROFILE_VIEW_UNSPECIFIED LoginProfileView = 0 // Includes POSIX and SSH key information. LoginProfileView_BASIC LoginProfileView = 1 // Include security key information for the user. LoginProfileView_SECURITY_KEY LoginProfileView = 2 )
func (LoginProfileView) Descriptor ¶ added in v1.8.0
func (LoginProfileView) Descriptor() protoreflect.EnumDescriptor
func (LoginProfileView) Enum ¶ added in v1.8.0
func (x LoginProfileView) Enum() *LoginProfileView
func (LoginProfileView) EnumDescriptor
deprecated
added in
v1.8.0
func (LoginProfileView) EnumDescriptor() ([]byte, []int)
Deprecated: Use LoginProfileView.Descriptor instead.
func (LoginProfileView) Number ¶ added in v1.8.0
func (x LoginProfileView) Number() protoreflect.EnumNumber
func (LoginProfileView) String ¶ added in v1.8.0
func (x LoginProfileView) String() string
func (LoginProfileView) Type ¶ added in v1.8.0
func (LoginProfileView) Type() protoreflect.EnumType
type OsLoginServiceClient ¶
type OsLoginServiceClient interface {
// Create an SSH public key
CreateSshPublicKey(ctx context.Context, in *CreateSshPublicKeyRequest, opts ...grpc.CallOption) (*commonpb.SshPublicKey, error)
// Deletes a POSIX account.
DeletePosixAccount(ctx context.Context, in *DeletePosixAccountRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Deletes an SSH public key.
DeleteSshPublicKey(ctx context.Context, in *DeleteSshPublicKeyRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
// Retrieves the profile information used for logging in to a virtual machine
// on Google Compute Engine.
GetLoginProfile(ctx context.Context, in *GetLoginProfileRequest, opts ...grpc.CallOption) (*LoginProfile, error)
// Retrieves an SSH public key.
GetSshPublicKey(ctx context.Context, in *GetSshPublicKeyRequest, opts ...grpc.CallOption) (*commonpb.SshPublicKey, error)
// Adds an SSH public key and returns the profile information. Default POSIX
// account information is set when no username and UID exist as part of the
// login profile.
ImportSshPublicKey(ctx context.Context, in *ImportSshPublicKeyRequest, opts ...grpc.CallOption) (*ImportSshPublicKeyResponse, error)
// Updates an SSH public key and returns the profile information. This method
// supports patch semantics.
UpdateSshPublicKey(ctx context.Context, in *UpdateSshPublicKeyRequest, opts ...grpc.CallOption) (*commonpb.SshPublicKey, error)
// Signs an SSH public key for a user to authenticate to an instance.
SignSshPublicKey(ctx context.Context, in *SignSshPublicKeyRequest, opts ...grpc.CallOption) (*SignSshPublicKeyResponse, error)
}
OsLoginServiceClient is the client API for OsLoginService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewOsLoginServiceClient ¶
func NewOsLoginServiceClient(cc grpc.ClientConnInterface) OsLoginServiceClient
type OsLoginServiceServer ¶
type OsLoginServiceServer interface {
// Create an SSH public key
CreateSshPublicKey(context.Context, *CreateSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
// Deletes a POSIX account.
DeletePosixAccount(context.Context, *DeletePosixAccountRequest) (*emptypb.Empty, error)
// Deletes an SSH public key.
DeleteSshPublicKey(context.Context, *DeleteSshPublicKeyRequest) (*emptypb.Empty, error)
// Retrieves the profile information used for logging in to a virtual machine
// on Google Compute Engine.
GetLoginProfile(context.Context, *GetLoginProfileRequest) (*LoginProfile, error)
// Retrieves an SSH public key.
GetSshPublicKey(context.Context, *GetSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
// Adds an SSH public key and returns the profile information. Default POSIX
// account information is set when no username and UID exist as part of the
// login profile.
ImportSshPublicKey(context.Context, *ImportSshPublicKeyRequest) (*ImportSshPublicKeyResponse, error)
// Updates an SSH public key and returns the profile information. This method
// supports patch semantics.
UpdateSshPublicKey(context.Context, *UpdateSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
// Signs an SSH public key for a user to authenticate to an instance.
SignSshPublicKey(context.Context, *SignSshPublicKeyRequest) (*SignSshPublicKeyResponse, error)
}
OsLoginServiceServer is the server API for OsLoginService service. All implementations should embed UnimplementedOsLoginServiceServer for forward compatibility
type SecurityKey ¶ added in v1.8.0
type SecurityKey struct {
// Public key text in SSH format, defined by
// [RFC4253]("https://www.ietf.org/rfc/rfc4253.txt") section 6.6.
PublicKey string `protobuf:"bytes,1,opt,name=public_key,json=publicKey,proto3" json:"public_key,omitempty"`
// Hardware-backed private key text in SSH format.
PrivateKey string `protobuf:"bytes,2,opt,name=private_key,json=privateKey,proto3" json:"private_key,omitempty"`
// The FIDO protocol type used to register this credential.
//
// Types that are valid to be assigned to ProtocolType:
//
// *SecurityKey_UniversalTwoFactor
// *SecurityKey_WebAuthn
ProtocolType isSecurityKey_ProtocolType `protobuf_oneof:"protocol_type"`
// The security key nickname explicitly set by the user.
DeviceNickname *string `protobuf:"bytes,5,opt,name=device_nickname,json=deviceNickname,proto3,oneof" json:"device_nickname,omitempty"`
// contains filtered or unexported fields
}
The credential information for a Google registered security key.
func (*SecurityKey) Descriptor
deprecated
added in
v1.8.0
func (*SecurityKey) Descriptor() ([]byte, []int)
Deprecated: Use SecurityKey.ProtoReflect.Descriptor instead.
func (*SecurityKey) GetDeviceNickname ¶ added in v1.11.0
func (x *SecurityKey) GetDeviceNickname() string
func (*SecurityKey) GetPrivateKey ¶ added in v1.8.0
func (x *SecurityKey) GetPrivateKey() string
func (*SecurityKey) GetProtocolType ¶ added in v1.8.0
func (x *SecurityKey) GetProtocolType() isSecurityKey_ProtocolType
func (*SecurityKey) GetPublicKey ¶ added in v1.8.0
func (x *SecurityKey) GetPublicKey() string
func (*SecurityKey) GetUniversalTwoFactor ¶ added in v1.8.0
func (x *SecurityKey) GetUniversalTwoFactor() *UniversalTwoFactor
func (*SecurityKey) GetWebAuthn ¶ added in v1.8.0
func (x *SecurityKey) GetWebAuthn() *WebAuthn
func (*SecurityKey) ProtoMessage ¶ added in v1.8.0
func (*SecurityKey) ProtoMessage()
func (*SecurityKey) ProtoReflect ¶ added in v1.8.0
func (x *SecurityKey) ProtoReflect() protoreflect.Message
func (*SecurityKey) Reset ¶ added in v1.8.0
func (x *SecurityKey) Reset()
func (*SecurityKey) String ¶ added in v1.8.0
func (x *SecurityKey) String() string
type SecurityKey_UniversalTwoFactor ¶ added in v1.8.0
type SecurityKey_UniversalTwoFactor struct {
// The U2F protocol type.
UniversalTwoFactor *UniversalTwoFactor `protobuf:"bytes,3,opt,name=universal_two_factor,json=universalTwoFactor,proto3,oneof"`
}
type SecurityKey_WebAuthn ¶ added in v1.8.0
type SecurityKey_WebAuthn struct {
// The Web Authentication protocol type.
WebAuthn *WebAuthn `protobuf:"bytes,4,opt,name=web_authn,json=webAuthn,proto3,oneof"`
}
type SignSshPublicKeyRequest ¶ added in v1.11.0
type SignSshPublicKeyRequest struct {
// The SSH public key to sign.
SshPublicKey string `protobuf:"bytes,1,opt,name=ssh_public_key,json=sshPublicKey,proto3" json:"ssh_public_key,omitempty"`
// The parent project and region for the signing request.
Parent string `protobuf:"bytes,2,opt,name=parent,proto3" json:"parent,omitempty"`
// contains filtered or unexported fields
}
func (*SignSshPublicKeyRequest) Descriptor
deprecated
added in
v1.11.0
func (*SignSshPublicKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use SignSshPublicKeyRequest.ProtoReflect.Descriptor instead.
func (*SignSshPublicKeyRequest) GetParent ¶ added in v1.11.0
func (x *SignSshPublicKeyRequest) GetParent() string
func (*SignSshPublicKeyRequest) GetSshPublicKey ¶ added in v1.11.0
func (x *SignSshPublicKeyRequest) GetSshPublicKey() string
func (*SignSshPublicKeyRequest) ProtoMessage ¶ added in v1.11.0
func (*SignSshPublicKeyRequest) ProtoMessage()
func (*SignSshPublicKeyRequest) ProtoReflect ¶ added in v1.11.0
func (x *SignSshPublicKeyRequest) ProtoReflect() protoreflect.Message
func (*SignSshPublicKeyRequest) Reset ¶ added in v1.11.0
func (x *SignSshPublicKeyRequest) Reset()
func (*SignSshPublicKeyRequest) String ¶ added in v1.11.0
func (x *SignSshPublicKeyRequest) String() string
type SignSshPublicKeyResponse ¶ added in v1.11.0
type SignSshPublicKeyResponse struct {
// The signed SSH public key to use in the SSH handshake.
SignedSshPublicKey string `protobuf:"bytes,1,opt,name=signed_ssh_public_key,json=signedSshPublicKey,proto3" json:"signed_ssh_public_key,omitempty"`
// contains filtered or unexported fields
}
func (*SignSshPublicKeyResponse) Descriptor
deprecated
added in
v1.11.0
func (*SignSshPublicKeyResponse) Descriptor() ([]byte, []int)
Deprecated: Use SignSshPublicKeyResponse.ProtoReflect.Descriptor instead.
func (*SignSshPublicKeyResponse) GetSignedSshPublicKey ¶ added in v1.11.0
func (x *SignSshPublicKeyResponse) GetSignedSshPublicKey() string
func (*SignSshPublicKeyResponse) ProtoMessage ¶ added in v1.11.0
func (*SignSshPublicKeyResponse) ProtoMessage()
func (*SignSshPublicKeyResponse) ProtoReflect ¶ added in v1.11.0
func (x *SignSshPublicKeyResponse) ProtoReflect() protoreflect.Message
func (*SignSshPublicKeyResponse) Reset ¶ added in v1.11.0
func (x *SignSshPublicKeyResponse) Reset()
func (*SignSshPublicKeyResponse) String ¶ added in v1.11.0
func (x *SignSshPublicKeyResponse) String() string
type UnimplementedOsLoginServiceServer ¶
type UnimplementedOsLoginServiceServer struct {
}
UnimplementedOsLoginServiceServer should be embedded to have forward compatible implementations.
func (UnimplementedOsLoginServiceServer) CreateSshPublicKey ¶ added in v1.8.0
func (UnimplementedOsLoginServiceServer) CreateSshPublicKey(context.Context, *CreateSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
func (UnimplementedOsLoginServiceServer) DeletePosixAccount ¶
func (UnimplementedOsLoginServiceServer) DeletePosixAccount(context.Context, *DeletePosixAccountRequest) (*emptypb.Empty, error)
func (UnimplementedOsLoginServiceServer) DeleteSshPublicKey ¶
func (UnimplementedOsLoginServiceServer) DeleteSshPublicKey(context.Context, *DeleteSshPublicKeyRequest) (*emptypb.Empty, error)
func (UnimplementedOsLoginServiceServer) GetLoginProfile ¶
func (UnimplementedOsLoginServiceServer) GetLoginProfile(context.Context, *GetLoginProfileRequest) (*LoginProfile, error)
func (UnimplementedOsLoginServiceServer) GetSshPublicKey ¶
func (UnimplementedOsLoginServiceServer) GetSshPublicKey(context.Context, *GetSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
func (UnimplementedOsLoginServiceServer) ImportSshPublicKey ¶
func (UnimplementedOsLoginServiceServer) ImportSshPublicKey(context.Context, *ImportSshPublicKeyRequest) (*ImportSshPublicKeyResponse, error)
func (UnimplementedOsLoginServiceServer) SignSshPublicKey ¶ added in v1.11.0
func (UnimplementedOsLoginServiceServer) SignSshPublicKey(context.Context, *SignSshPublicKeyRequest) (*SignSshPublicKeyResponse, error)
func (UnimplementedOsLoginServiceServer) UpdateSshPublicKey ¶
func (UnimplementedOsLoginServiceServer) UpdateSshPublicKey(context.Context, *UpdateSshPublicKeyRequest) (*commonpb.SshPublicKey, error)
type UniversalTwoFactor ¶ added in v1.8.0
type UniversalTwoFactor struct {
// Application ID for the U2F protocol.
AppId string `protobuf:"bytes,1,opt,name=app_id,json=appId,proto3" json:"app_id,omitempty"`
// contains filtered or unexported fields
}
Security key information specific to the U2F protocol.
func (*UniversalTwoFactor) Descriptor
deprecated
added in
v1.8.0
func (*UniversalTwoFactor) Descriptor() ([]byte, []int)
Deprecated: Use UniversalTwoFactor.ProtoReflect.Descriptor instead.
func (*UniversalTwoFactor) GetAppId ¶ added in v1.8.0
func (x *UniversalTwoFactor) GetAppId() string
func (*UniversalTwoFactor) ProtoMessage ¶ added in v1.8.0
func (*UniversalTwoFactor) ProtoMessage()
func (*UniversalTwoFactor) ProtoReflect ¶ added in v1.8.0
func (x *UniversalTwoFactor) ProtoReflect() protoreflect.Message
func (*UniversalTwoFactor) Reset ¶ added in v1.8.0
func (x *UniversalTwoFactor) Reset()
func (*UniversalTwoFactor) String ¶ added in v1.8.0
func (x *UniversalTwoFactor) String() string
type UnsafeOsLoginServiceServer ¶ added in v1.14.7
type UnsafeOsLoginServiceServer interface {
// contains filtered or unexported methods
}
UnsafeOsLoginServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OsLoginServiceServer will result in compilation errors.
type UpdateSshPublicKeyRequest ¶
type UpdateSshPublicKeyRequest struct {
// Required. The fingerprint of the public key to update. Public keys are
// identified by their SHA-256 fingerprint. The fingerprint of the public key
// is in format `users/{user}/sshPublicKeys/{fingerprint}`.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Required. The SSH public key and expiration time.
SshPublicKey *commonpb.SshPublicKey `protobuf:"bytes,2,opt,name=ssh_public_key,json=sshPublicKey,proto3" json:"ssh_public_key,omitempty"`
// Mask to control which fields get updated. Updates all if not present.
UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,3,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
// contains filtered or unexported fields
}
A request message for updating an SSH public key.
func (*UpdateSshPublicKeyRequest) Descriptor
deprecated
func (*UpdateSshPublicKeyRequest) Descriptor() ([]byte, []int)
Deprecated: Use UpdateSshPublicKeyRequest.ProtoReflect.Descriptor instead.
func (*UpdateSshPublicKeyRequest) GetName ¶
func (x *UpdateSshPublicKeyRequest) GetName() string
func (*UpdateSshPublicKeyRequest) GetSshPublicKey ¶
func (x *UpdateSshPublicKeyRequest) GetSshPublicKey() *commonpb.SshPublicKey
func (*UpdateSshPublicKeyRequest) GetUpdateMask ¶
func (x *UpdateSshPublicKeyRequest) GetUpdateMask() *fieldmaskpb.FieldMask
func (*UpdateSshPublicKeyRequest) ProtoMessage ¶
func (*UpdateSshPublicKeyRequest) ProtoMessage()
func (*UpdateSshPublicKeyRequest) ProtoReflect ¶
func (x *UpdateSshPublicKeyRequest) ProtoReflect() protoreflect.Message
func (*UpdateSshPublicKeyRequest) Reset ¶
func (x *UpdateSshPublicKeyRequest) Reset()
func (*UpdateSshPublicKeyRequest) String ¶
func (x *UpdateSshPublicKeyRequest) String() string
type WebAuthn ¶ added in v1.8.0
type WebAuthn struct {
// Relying party ID for Web Authentication.
RpId string `protobuf:"bytes,1,opt,name=rp_id,json=rpId,proto3" json:"rp_id,omitempty"`
// contains filtered or unexported fields
}
Security key information specific to the Web Authentication protocol.
func (*WebAuthn) Descriptor
deprecated
added in
v1.8.0
func (*WebAuthn) ProtoMessage ¶ added in v1.8.0
func (*WebAuthn) ProtoMessage()
func (*WebAuthn) ProtoReflect ¶ added in v1.8.0
func (x *WebAuthn) ProtoReflect() protoreflect.Message