package oslogin
import "cloud.google.com/go/oslogin/apiv1"
Package oslogin is an auto-generated package for the Google Cloud OS Login API.
NOTE: This package is in alpha. It is not stable, and is likely to change.
Manages OS login configuration for Google account users.
Use of Context
The ctx passed to NewClient is used for authentication requests and for creating the underlying connection, but is not used for subsequent calls. Individual methods on the client use the ctx given to them.
To close the open connection, use the Close() method.
For information about setting deadlines, reusing contexts, and more please visit godoc.org/cloud.google.com/go.
Index ¶
- func DefaultAuthScopes() []string
- type CallOptions
- type Client
- func NewClient(ctx context.Context, opts ...option.ClientOption) (*Client, error)
- func (c *Client) Close() error
- func (c *Client) Connection() *grpc.ClientConn
- func (c *Client) DeletePosixAccount(ctx context.Context, req *osloginpb.DeletePosixAccountRequest, opts ...gax.CallOption) error
- func (c *Client) DeleteSshPublicKey(ctx context.Context, req *osloginpb.DeleteSshPublicKeyRequest, opts ...gax.CallOption) error
- func (c *Client) GetLoginProfile(ctx context.Context, req *osloginpb.GetLoginProfileRequest, opts ...gax.CallOption) (*osloginpb.LoginProfile, error)
- func (c *Client) GetSshPublicKey(ctx context.Context, req *osloginpb.GetSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
- func (c *Client) ImportSshPublicKey(ctx context.Context, req *osloginpb.ImportSshPublicKeyRequest, opts ...gax.CallOption) (*osloginpb.ImportSshPublicKeyResponse, error)
- func (c *Client) UpdateSshPublicKey(ctx context.Context, req *osloginpb.UpdateSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
Examples ¶
- Client.DeletePosixAccount
- Client.DeleteSshPublicKey
- Client.GetLoginProfile
- Client.GetSshPublicKey
- Client.ImportSshPublicKey
- Client.UpdateSshPublicKey
- NewClient
Functions ¶
func DefaultAuthScopes ¶
func DefaultAuthScopes() []string
DefaultAuthScopes reports the default set of authentication scopes to use with this package.
Types ¶
type CallOptions ¶
type CallOptions struct {
DeletePosixAccount []gax.CallOption
DeleteSshPublicKey []gax.CallOption
GetLoginProfile []gax.CallOption
GetSshPublicKey []gax.CallOption
ImportSshPublicKey []gax.CallOption
UpdateSshPublicKey []gax.CallOption
}
CallOptions contains the retry settings for each method of Client.
type Client ¶
type Client struct {
// The call options for this service.
CallOptions *CallOptions
// contains filtered or unexported fields
}
Client is a client for interacting with Google Cloud OS Login API.
Methods, except Close, may be called concurrently. However, fields must not be modified concurrently with method calls.
func NewClient ¶
NewClient creates a new os login service client.
Cloud OS Login API
The Cloud OS Login API allows you to manage users and their associated SSH public keys for logging into virtual machines on Google Cloud Platform.
func (*Client) Close ¶
Close closes the connection to the API service. The user should invoke this when the client is no longer required.
func (*Client) Connection ¶
func (c *Client) Connection() *grpc.ClientConn
Connection returns the client's connection to the API service.
func (*Client) DeletePosixAccount ¶
func (c *Client) DeletePosixAccount(ctx context.Context, req *osloginpb.DeletePosixAccountRequest, opts ...gax.CallOption) error
DeletePosixAccount deletes a POSIX account.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "google.golang.org/genproto/googleapis/cloud/oslogin/v1"
)
func main() {
ctx := context.Background()
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
req := &osloginpb.DeletePosixAccountRequest{
// TODO: Fill request struct fields.
}
err = c.DeletePosixAccount(ctx, req)
if err != nil {
// TODO: Handle error.
}
}
func (*Client) DeleteSshPublicKey ¶
func (c *Client) DeleteSshPublicKey(ctx context.Context, req *osloginpb.DeleteSshPublicKeyRequest, opts ...gax.CallOption) error
DeleteSshPublicKey deletes an SSH public key.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "google.golang.org/genproto/googleapis/cloud/oslogin/v1"
)
func main() {
ctx := context.Background()
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
req := &osloginpb.DeleteSshPublicKeyRequest{
// TODO: Fill request struct fields.
}
err = c.DeleteSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
}
func (*Client) GetLoginProfile ¶
func (c *Client) GetLoginProfile(ctx context.Context, req *osloginpb.GetLoginProfileRequest, opts ...gax.CallOption) (*osloginpb.LoginProfile, error)
GetLoginProfile retrieves the profile information used for logging in to a virtual machine
on Google Compute Engine.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "google.golang.org/genproto/googleapis/cloud/oslogin/v1"
)
func main() {
ctx := context.Background()
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
req := &osloginpb.GetLoginProfileRequest{
// TODO: Fill request struct fields.
}
resp, err := c.GetLoginProfile(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
func (*Client) GetSshPublicKey ¶
func (c *Client) GetSshPublicKey(ctx context.Context, req *osloginpb.GetSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
GetSshPublicKey retrieves an SSH public key.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "google.golang.org/genproto/googleapis/cloud/oslogin/v1"
)
func main() {
ctx := context.Background()
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
req := &osloginpb.GetSshPublicKeyRequest{
// TODO: Fill request struct fields.
}
resp, err := c.GetSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
func (*Client) ImportSshPublicKey ¶
func (c *Client) ImportSshPublicKey(ctx context.Context, req *osloginpb.ImportSshPublicKeyRequest, opts ...gax.CallOption) (*osloginpb.ImportSshPublicKeyResponse, error)
ImportSshPublicKey adds an SSH public key and returns the profile information. Default POSIX
account information is set when no username and UID exist as part of the
login profile.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "google.golang.org/genproto/googleapis/cloud/oslogin/v1"
)
func main() {
ctx := context.Background()
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
req := &osloginpb.ImportSshPublicKeyRequest{
// TODO: Fill request struct fields.
}
resp, err := c.ImportSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
func (*Client) UpdateSshPublicKey ¶
func (c *Client) UpdateSshPublicKey(ctx context.Context, req *osloginpb.UpdateSshPublicKeyRequest, opts ...gax.CallOption) (*commonpb.SshPublicKey, error)
UpdateSshPublicKey updates an SSH public key and returns the profile information. This method
supports patch semantics.
Code:play
Example¶
package main
import (
"context"
oslogin "cloud.google.com/go/oslogin/apiv1"
osloginpb "google.golang.org/genproto/googleapis/cloud/oslogin/v1"
)
func main() {
ctx := context.Background()
c, err := oslogin.NewClient(ctx)
if err != nil {
// TODO: Handle error.
}
req := &osloginpb.UpdateSshPublicKeyRequest{
// TODO: Fill request struct fields.
}
resp, err := c.UpdateSshPublicKey(ctx, req)
if err != nil {
// TODO: Handle error.
}
// TODO: Use resp.
_ = resp
}
Source Files ¶
doc.go os_login_client.go
- Version
- v0.37.3-alpha
- Published
- Apr 8, 2019
- Platform
- linux/amd64
- Imports
- 14 packages
- Last checked
- 33 minutes ago –
Tools for package owners.